@@ -14,35 +14,66 @@
 #' ic2 <- ical(ic_df)
 #' class(ic2)
 #' attributes(ic2)
-ical <- function(x, ic_attributes = NULL) {
-  is_df <- is.data.frame(x)
-  if(methods::is(x, "character")) {
+ical <- function(
+    x,
+    ic_attributes = NULL) {
+
+  assert(
+    inherits(x = x, what = "character") | inherits(x = x, what = "data.frame"),
+    error_message = c(
+      "x" = sprintf(
+        "{.arg x} is passed as {.cls %s}.",
+        class(x)
+      ),
+      "i" = "{.arg x} has to be {.cls character} or {.cls data.frame}."
+    )
+  )
+
+  # is_df <- is.data.frame(x)
+  if (inherits(x = x, what = "character")) {
+
     ical_df <- ic_dataframe(x)
     ical_tibble <- tibble::as_tibble(ical_df)
-    if(is.null(ic_attributes)) {
+
+    if (is.null(ic_attributes)) {
+
       attr(ical_tibble, "ical") <- ic_attributes_vec(x)
+
     } else {
+
       attr(ical_tibble, "ical") <- ic_attributes
     }
 
   } else {
-    if(!is_df) stop("x must be a data frame or charcter strings")
-    n <- names(x)
-    is_core = calendar::properties_core %in% n
-    if(!all(is_core)) {
-      stop(paste0(
-        "x must contain column names: ",
-        paste0(calendar::properties_core, collapse = ", ")
-      ))
-    }
+
+    is_core <- calendar::properties_core %in% names(x)
+
+    assert(
+      all(is_core),
+      error_message = c(
+        "x" = paste(
+          "{.arg x} must contain the column names",
+          paste0(calendar::properties_core, collapse = ", ")
+        )
+      )
+    )
+
     ical_tibble <- tibble::as_tibble(x)
-    if(is.null(ic_attributes)) {
+
+    if (is.null(ic_attributes)) {
+
       attr(ical_tibble, "ical") <- ic_attributes_vec()
+
     } else {
+
       attr(ical_tibble, "ical") <- ic_attributes
+
     }
+
   }
+
   class(ical_tibble) <- c("ical", class(ical_tibble))
+
   ical_tibble
 }
 #' Extract attributes from ical text
@@ -54,20 +85,23 @@ ical <- function(x, ic_attributes = NULL) {
 ic_attributes_vec <- function(
   x = NULL,
   ic_attributes = c(
-    BEGIN = "VCALENDAR",
-    PRODID = "ATFutures/calendar",
-    VERSION = "2.0",
+    BEGIN    = "VCALENDAR",
+    PRODID   =  "ATFutures/calendar",
+    VERSION  = "2.0",
     CALSCALE = "GREGORIAN",
-    METHOD = "PUBLISH"
-    )
-  ) {
+    METHOD   = "PUBLISH"
+    )) {
+
   if(is.null(x)) {
     return(ic_attributes)
   }
+
   line_first_event <- grep("BEGIN:VEVENT", x)[1]
   x_attributes <- x[1:(line_first_event - 1)]
+
   ic_vector(x_attributes, pattern = "*")
 }
+
 #' Convert ical object to character strings of attributes
 #'
 #' @param ic object of class `ical`
@@ -84,6 +118,7 @@ ic_character <- function(ic, zulu = FALSE) {
   char_events <- ic_char_event(ic, zulu)
   c(char_attributes, char_events, "END:VCALENDAR")
 }
+
 #' Convert ical object to character strings of events
 #'
 #' @inheritParams ic_character
